@@ -124,7 +124,7 @@ class BertSTEMForTextClassification:
         acc = accuracy_score(labels, preds)
         bacc = balanced_accuracy_score(labels, preds)
         return {
-            'bacc': bacc
+            'bacc': bacc,
             'accuracy': acc,
             'f1': f1,
             'precision': precision,
